# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetNetworkSecurityPerimeterProfileResult',
    'AwaitableGetNetworkSecurityPerimeterProfileResult',
    'get_network_security_perimeter_profile',
    'get_network_security_perimeter_profile_output',
]

@pulumi.output_type
class GetNetworkSecurityPerimeterProfileResult:
    """
    A collection of values returned by getNetworkSecurityPerimeterProfile.
    """
    def __init__(__self__, id=None, name=None, network_security_perimeter_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_security_perimeter_id and not isinstance(network_security_perimeter_id, str):
            raise TypeError("Expected argument 'network_security_perimeter_id' to be a str")
        pulumi.set(__self__, "network_security_perimeter_id", network_security_perimeter_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkSecurityPerimeterId")
    def network_security_perimeter_id(self) -> _builtins.str:
        return pulumi.get(self, "network_security_perimeter_id")


class AwaitableGetNetworkSecurityPerimeterProfileResult(GetNetworkSecurityPerimeterProfileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkSecurityPerimeterProfileResult(
            id=self.id,
            name=self.name,
            network_security_perimeter_id=self.network_security_perimeter_id)


def get_network_security_perimeter_profile(name: Optional[_builtins.str] = None,
                                           network_security_perimeter_id: Optional[_builtins.str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkSecurityPerimeterProfileResult:
    """
    Use this data source to access information about an existing Network Security Perimeter Profile.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_network_security_perimeter(name="existing",
        resource_group_name="existing")
    example_get_network_security_perimeter_profile = azure.network.get_network_security_perimeter_profile(name="existing",
        network_security_perimeter_id=example.id)
    pulumi.export("id", example_get_network_security_perimeter_profile.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Network` - 2025-01-01


    :param _builtins.str name: The name of this Network Security Perimeter Profile.
    :param _builtins.str network_security_perimeter_id: The ID of the Network Security Perimeter.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['networkSecurityPerimeterId'] = network_security_perimeter_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:network/getNetworkSecurityPerimeterProfile:getNetworkSecurityPerimeterProfile', __args__, opts=opts, typ=GetNetworkSecurityPerimeterProfileResult).value

    return AwaitableGetNetworkSecurityPerimeterProfileResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        network_security_perimeter_id=pulumi.get(__ret__, 'network_security_perimeter_id'))
def get_network_security_perimeter_profile_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                                  network_security_perimeter_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkSecurityPerimeterProfileResult]:
    """
    Use this data source to access information about an existing Network Security Perimeter Profile.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_network_security_perimeter(name="existing",
        resource_group_name="existing")
    example_get_network_security_perimeter_profile = azure.network.get_network_security_perimeter_profile(name="existing",
        network_security_perimeter_id=example.id)
    pulumi.export("id", example_get_network_security_perimeter_profile.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Network` - 2025-01-01


    :param _builtins.str name: The name of this Network Security Perimeter Profile.
    :param _builtins.str network_security_perimeter_id: The ID of the Network Security Perimeter.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['networkSecurityPerimeterId'] = network_security_perimeter_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:network/getNetworkSecurityPerimeterProfile:getNetworkSecurityPerimeterProfile', __args__, opts=opts, typ=GetNetworkSecurityPerimeterProfileResult)
    return __ret__.apply(lambda __response__: GetNetworkSecurityPerimeterProfileResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        network_security_perimeter_id=pulumi.get(__response__, 'network_security_perimeter_id')))
