# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ServerIpv4FirewallRuleArgs',
    'ServerIpv4FirewallRuleArgsDict',
]

class ServerIpv4FirewallRuleArgsDict(TypedDict):
    name: pulumi.Input[_builtins.str]
    """
    Specifies the name of the firewall rule.
    """
    range_end: pulumi.Input[_builtins.str]
    """
    End of the firewall rule range as IPv4 address.
    """
    range_start: pulumi.Input[_builtins.str]
    """
    Start of the firewall rule range as IPv4 address.
    """

@pulumi.input_type
class ServerIpv4FirewallRuleArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[_builtins.str],
                 range_end: pulumi.Input[_builtins.str],
                 range_start: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] name: Specifies the name of the firewall rule.
        :param pulumi.Input[_builtins.str] range_end: End of the firewall rule range as IPv4 address.
        :param pulumi.Input[_builtins.str] range_start: Start of the firewall rule range as IPv4 address.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "range_end", range_end)
        pulumi.set(__self__, "range_start", range_start)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the name of the firewall rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="rangeEnd")
    def range_end(self) -> pulumi.Input[_builtins.str]:
        """
        End of the firewall rule range as IPv4 address.
        """
        return pulumi.get(self, "range_end")

    @range_end.setter
    def range_end(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "range_end", value)

    @_builtins.property
    @pulumi.getter(name="rangeStart")
    def range_start(self) -> pulumi.Input[_builtins.str]:
        """
        Start of the firewall rule range as IPv4 address.
        """
        return pulumi.get(self, "range_start")

    @range_start.setter
    def range_start(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "range_start", value)


