# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAutonomousDatabaseCloneFromBackupResult',
    'AwaitableGetAutonomousDatabaseCloneFromBackupResult',
    'get_autonomous_database_clone_from_backup',
    'get_autonomous_database_clone_from_backup_output',
]

@pulumi.output_type
class GetAutonomousDatabaseCloneFromBackupResult:
    """
    A collection of values returned by getAutonomousDatabaseCloneFromBackup.
    """
    def __init__(__self__, actual_used_data_storage_size_in_tb=None, allocated_storage_size_in_tb=None, allowed_ip_addresses=None, auto_scaling_enabled=None, auto_scaling_for_storage_enabled=None, available_upgrade_versions=None, backup_retention_period_in_days=None, character_set=None, compute_count=None, compute_model=None, connection_strings=None, cpu_core_count=None, customer_contacts=None, data_storage_size_in_gb=None, data_storage_size_in_tb=None, database_version=None, database_workload=None, display_name=None, failed_data_recovery_in_seconds=None, id=None, in_memory_area_in_gb=None, license_model=None, lifecycle_details=None, lifecycle_state=None, local_adg_auto_failover_max_data_loss_limit_in_seconds=None, local_data_guard_enabled=None, location=None, long_term_backup_schedules=None, memory_per_oracle_compute_unit_in_gb=None, mtls_connection_required=None, name=None, national_character_set=None, next_long_term_backup_timestamp=None, oci_url=None, ocid=None, peer_database_ids=None, preview=None, preview_version_with_service_terms_accepted=None, private_endpoint_ip=None, private_endpoint_label=None, private_endpoint_url=None, provisionable_cpuses=None, remote_data_guard_enabled=None, resource_group_name=None, service_console_url=None, source_autonomous_database_id=None, sql_web_developer_url=None, subnet_id=None, supported_regions_to_clone_tos=None, tags=None, time_created_in_utc=None, time_data_guard_role_changed_in_utc=None, time_deletion_of_free_autonomous_database_in_utc=None, time_local_data_guard_enabled_in_utc=None, time_maintenance_begin_in_utc=None, time_maintenance_end_in_utc=None, time_of_last_failover_in_utc=None, time_of_last_refresh_in_utc=None, time_of_last_refresh_point_in_utc=None, time_of_last_switchover_in_utc=None, time_reclamation_of_free_autonomous_database_in_utc=None, used_data_storage_size_in_gb=None, used_data_storage_size_in_tb=None, virtual_network_id=None):
        if actual_used_data_storage_size_in_tb and not isinstance(actual_used_data_storage_size_in_tb, float):
            raise TypeError("Expected argument 'actual_used_data_storage_size_in_tb' to be a float")
        pulumi.set(__self__, "actual_used_data_storage_size_in_tb", actual_used_data_storage_size_in_tb)
        if allocated_storage_size_in_tb and not isinstance(allocated_storage_size_in_tb, float):
            raise TypeError("Expected argument 'allocated_storage_size_in_tb' to be a float")
        pulumi.set(__self__, "allocated_storage_size_in_tb", allocated_storage_size_in_tb)
        if allowed_ip_addresses and not isinstance(allowed_ip_addresses, list):
            raise TypeError("Expected argument 'allowed_ip_addresses' to be a list")
        pulumi.set(__self__, "allowed_ip_addresses", allowed_ip_addresses)
        if auto_scaling_enabled and not isinstance(auto_scaling_enabled, bool):
            raise TypeError("Expected argument 'auto_scaling_enabled' to be a bool")
        pulumi.set(__self__, "auto_scaling_enabled", auto_scaling_enabled)
        if auto_scaling_for_storage_enabled and not isinstance(auto_scaling_for_storage_enabled, bool):
            raise TypeError("Expected argument 'auto_scaling_for_storage_enabled' to be a bool")
        pulumi.set(__self__, "auto_scaling_for_storage_enabled", auto_scaling_for_storage_enabled)
        if available_upgrade_versions and not isinstance(available_upgrade_versions, list):
            raise TypeError("Expected argument 'available_upgrade_versions' to be a list")
        pulumi.set(__self__, "available_upgrade_versions", available_upgrade_versions)
        if backup_retention_period_in_days and not isinstance(backup_retention_period_in_days, int):
            raise TypeError("Expected argument 'backup_retention_period_in_days' to be a int")
        pulumi.set(__self__, "backup_retention_period_in_days", backup_retention_period_in_days)
        if character_set and not isinstance(character_set, str):
            raise TypeError("Expected argument 'character_set' to be a str")
        pulumi.set(__self__, "character_set", character_set)
        if compute_count and not isinstance(compute_count, float):
            raise TypeError("Expected argument 'compute_count' to be a float")
        pulumi.set(__self__, "compute_count", compute_count)
        if compute_model and not isinstance(compute_model, str):
            raise TypeError("Expected argument 'compute_model' to be a str")
        pulumi.set(__self__, "compute_model", compute_model)
        if connection_strings and not isinstance(connection_strings, list):
            raise TypeError("Expected argument 'connection_strings' to be a list")
        pulumi.set(__self__, "connection_strings", connection_strings)
        if cpu_core_count and not isinstance(cpu_core_count, int):
            raise TypeError("Expected argument 'cpu_core_count' to be a int")
        pulumi.set(__self__, "cpu_core_count", cpu_core_count)
        if customer_contacts and not isinstance(customer_contacts, list):
            raise TypeError("Expected argument 'customer_contacts' to be a list")
        pulumi.set(__self__, "customer_contacts", customer_contacts)
        if data_storage_size_in_gb and not isinstance(data_storage_size_in_gb, int):
            raise TypeError("Expected argument 'data_storage_size_in_gb' to be a int")
        pulumi.set(__self__, "data_storage_size_in_gb", data_storage_size_in_gb)
        if data_storage_size_in_tb and not isinstance(data_storage_size_in_tb, int):
            raise TypeError("Expected argument 'data_storage_size_in_tb' to be a int")
        pulumi.set(__self__, "data_storage_size_in_tb", data_storage_size_in_tb)
        if database_version and not isinstance(database_version, str):
            raise TypeError("Expected argument 'database_version' to be a str")
        pulumi.set(__self__, "database_version", database_version)
        if database_workload and not isinstance(database_workload, str):
            raise TypeError("Expected argument 'database_workload' to be a str")
        pulumi.set(__self__, "database_workload", database_workload)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if failed_data_recovery_in_seconds and not isinstance(failed_data_recovery_in_seconds, int):
            raise TypeError("Expected argument 'failed_data_recovery_in_seconds' to be a int")
        pulumi.set(__self__, "failed_data_recovery_in_seconds", failed_data_recovery_in_seconds)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if in_memory_area_in_gb and not isinstance(in_memory_area_in_gb, int):
            raise TypeError("Expected argument 'in_memory_area_in_gb' to be a int")
        pulumi.set(__self__, "in_memory_area_in_gb", in_memory_area_in_gb)
        if license_model and not isinstance(license_model, str):
            raise TypeError("Expected argument 'license_model' to be a str")
        pulumi.set(__self__, "license_model", license_model)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if lifecycle_state and not isinstance(lifecycle_state, str):
            raise TypeError("Expected argument 'lifecycle_state' to be a str")
        pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if local_adg_auto_failover_max_data_loss_limit_in_seconds and not isinstance(local_adg_auto_failover_max_data_loss_limit_in_seconds, int):
            raise TypeError("Expected argument 'local_adg_auto_failover_max_data_loss_limit_in_seconds' to be a int")
        pulumi.set(__self__, "local_adg_auto_failover_max_data_loss_limit_in_seconds", local_adg_auto_failover_max_data_loss_limit_in_seconds)
        if local_data_guard_enabled and not isinstance(local_data_guard_enabled, bool):
            raise TypeError("Expected argument 'local_data_guard_enabled' to be a bool")
        pulumi.set(__self__, "local_data_guard_enabled", local_data_guard_enabled)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if long_term_backup_schedules and not isinstance(long_term_backup_schedules, list):
            raise TypeError("Expected argument 'long_term_backup_schedules' to be a list")
        pulumi.set(__self__, "long_term_backup_schedules", long_term_backup_schedules)
        if memory_per_oracle_compute_unit_in_gb and not isinstance(memory_per_oracle_compute_unit_in_gb, int):
            raise TypeError("Expected argument 'memory_per_oracle_compute_unit_in_gb' to be a int")
        pulumi.set(__self__, "memory_per_oracle_compute_unit_in_gb", memory_per_oracle_compute_unit_in_gb)
        if mtls_connection_required and not isinstance(mtls_connection_required, bool):
            raise TypeError("Expected argument 'mtls_connection_required' to be a bool")
        pulumi.set(__self__, "mtls_connection_required", mtls_connection_required)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if national_character_set and not isinstance(national_character_set, str):
            raise TypeError("Expected argument 'national_character_set' to be a str")
        pulumi.set(__self__, "national_character_set", national_character_set)
        if next_long_term_backup_timestamp and not isinstance(next_long_term_backup_timestamp, str):
            raise TypeError("Expected argument 'next_long_term_backup_timestamp' to be a str")
        pulumi.set(__self__, "next_long_term_backup_timestamp", next_long_term_backup_timestamp)
        if oci_url and not isinstance(oci_url, str):
            raise TypeError("Expected argument 'oci_url' to be a str")
        pulumi.set(__self__, "oci_url", oci_url)
        if ocid and not isinstance(ocid, str):
            raise TypeError("Expected argument 'ocid' to be a str")
        pulumi.set(__self__, "ocid", ocid)
        if peer_database_ids and not isinstance(peer_database_ids, list):
            raise TypeError("Expected argument 'peer_database_ids' to be a list")
        pulumi.set(__self__, "peer_database_ids", peer_database_ids)
        if preview and not isinstance(preview, bool):
            raise TypeError("Expected argument 'preview' to be a bool")
        pulumi.set(__self__, "preview", preview)
        if preview_version_with_service_terms_accepted and not isinstance(preview_version_with_service_terms_accepted, bool):
            raise TypeError("Expected argument 'preview_version_with_service_terms_accepted' to be a bool")
        pulumi.set(__self__, "preview_version_with_service_terms_accepted", preview_version_with_service_terms_accepted)
        if private_endpoint_ip and not isinstance(private_endpoint_ip, str):
            raise TypeError("Expected argument 'private_endpoint_ip' to be a str")
        pulumi.set(__self__, "private_endpoint_ip", private_endpoint_ip)
        if private_endpoint_label and not isinstance(private_endpoint_label, str):
            raise TypeError("Expected argument 'private_endpoint_label' to be a str")
        pulumi.set(__self__, "private_endpoint_label", private_endpoint_label)
        if private_endpoint_url and not isinstance(private_endpoint_url, str):
            raise TypeError("Expected argument 'private_endpoint_url' to be a str")
        pulumi.set(__self__, "private_endpoint_url", private_endpoint_url)
        if provisionable_cpuses and not isinstance(provisionable_cpuses, list):
            raise TypeError("Expected argument 'provisionable_cpuses' to be a list")
        pulumi.set(__self__, "provisionable_cpuses", provisionable_cpuses)
        if remote_data_guard_enabled and not isinstance(remote_data_guard_enabled, bool):
            raise TypeError("Expected argument 'remote_data_guard_enabled' to be a bool")
        pulumi.set(__self__, "remote_data_guard_enabled", remote_data_guard_enabled)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if service_console_url and not isinstance(service_console_url, str):
            raise TypeError("Expected argument 'service_console_url' to be a str")
        pulumi.set(__self__, "service_console_url", service_console_url)
        if source_autonomous_database_id and not isinstance(source_autonomous_database_id, str):
            raise TypeError("Expected argument 'source_autonomous_database_id' to be a str")
        pulumi.set(__self__, "source_autonomous_database_id", source_autonomous_database_id)
        if sql_web_developer_url and not isinstance(sql_web_developer_url, str):
            raise TypeError("Expected argument 'sql_web_developer_url' to be a str")
        pulumi.set(__self__, "sql_web_developer_url", sql_web_developer_url)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if supported_regions_to_clone_tos and not isinstance(supported_regions_to_clone_tos, list):
            raise TypeError("Expected argument 'supported_regions_to_clone_tos' to be a list")
        pulumi.set(__self__, "supported_regions_to_clone_tos", supported_regions_to_clone_tos)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if time_created_in_utc and not isinstance(time_created_in_utc, str):
            raise TypeError("Expected argument 'time_created_in_utc' to be a str")
        pulumi.set(__self__, "time_created_in_utc", time_created_in_utc)
        if time_data_guard_role_changed_in_utc and not isinstance(time_data_guard_role_changed_in_utc, str):
            raise TypeError("Expected argument 'time_data_guard_role_changed_in_utc' to be a str")
        pulumi.set(__self__, "time_data_guard_role_changed_in_utc", time_data_guard_role_changed_in_utc)
        if time_deletion_of_free_autonomous_database_in_utc and not isinstance(time_deletion_of_free_autonomous_database_in_utc, str):
            raise TypeError("Expected argument 'time_deletion_of_free_autonomous_database_in_utc' to be a str")
        pulumi.set(__self__, "time_deletion_of_free_autonomous_database_in_utc", time_deletion_of_free_autonomous_database_in_utc)
        if time_local_data_guard_enabled_in_utc and not isinstance(time_local_data_guard_enabled_in_utc, str):
            raise TypeError("Expected argument 'time_local_data_guard_enabled_in_utc' to be a str")
        pulumi.set(__self__, "time_local_data_guard_enabled_in_utc", time_local_data_guard_enabled_in_utc)
        if time_maintenance_begin_in_utc and not isinstance(time_maintenance_begin_in_utc, str):
            raise TypeError("Expected argument 'time_maintenance_begin_in_utc' to be a str")
        pulumi.set(__self__, "time_maintenance_begin_in_utc", time_maintenance_begin_in_utc)
        if time_maintenance_end_in_utc and not isinstance(time_maintenance_end_in_utc, str):
            raise TypeError("Expected argument 'time_maintenance_end_in_utc' to be a str")
        pulumi.set(__self__, "time_maintenance_end_in_utc", time_maintenance_end_in_utc)
        if time_of_last_failover_in_utc and not isinstance(time_of_last_failover_in_utc, str):
            raise TypeError("Expected argument 'time_of_last_failover_in_utc' to be a str")
        pulumi.set(__self__, "time_of_last_failover_in_utc", time_of_last_failover_in_utc)
        if time_of_last_refresh_in_utc and not isinstance(time_of_last_refresh_in_utc, str):
            raise TypeError("Expected argument 'time_of_last_refresh_in_utc' to be a str")
        pulumi.set(__self__, "time_of_last_refresh_in_utc", time_of_last_refresh_in_utc)
        if time_of_last_refresh_point_in_utc and not isinstance(time_of_last_refresh_point_in_utc, str):
            raise TypeError("Expected argument 'time_of_last_refresh_point_in_utc' to be a str")
        pulumi.set(__self__, "time_of_last_refresh_point_in_utc", time_of_last_refresh_point_in_utc)
        if time_of_last_switchover_in_utc and not isinstance(time_of_last_switchover_in_utc, str):
            raise TypeError("Expected argument 'time_of_last_switchover_in_utc' to be a str")
        pulumi.set(__self__, "time_of_last_switchover_in_utc", time_of_last_switchover_in_utc)
        if time_reclamation_of_free_autonomous_database_in_utc and not isinstance(time_reclamation_of_free_autonomous_database_in_utc, str):
            raise TypeError("Expected argument 'time_reclamation_of_free_autonomous_database_in_utc' to be a str")
        pulumi.set(__self__, "time_reclamation_of_free_autonomous_database_in_utc", time_reclamation_of_free_autonomous_database_in_utc)
        if used_data_storage_size_in_gb and not isinstance(used_data_storage_size_in_gb, int):
            raise TypeError("Expected argument 'used_data_storage_size_in_gb' to be a int")
        pulumi.set(__self__, "used_data_storage_size_in_gb", used_data_storage_size_in_gb)
        if used_data_storage_size_in_tb and not isinstance(used_data_storage_size_in_tb, int):
            raise TypeError("Expected argument 'used_data_storage_size_in_tb' to be a int")
        pulumi.set(__self__, "used_data_storage_size_in_tb", used_data_storage_size_in_tb)
        if virtual_network_id and not isinstance(virtual_network_id, str):
            raise TypeError("Expected argument 'virtual_network_id' to be a str")
        pulumi.set(__self__, "virtual_network_id", virtual_network_id)

    @_builtins.property
    @pulumi.getter(name="actualUsedDataStorageSizeInTb")
    def actual_used_data_storage_size_in_tb(self) -> _builtins.float:
        """
        The current amount of storage in use for user and system data in terabytes.
        """
        return pulumi.get(self, "actual_used_data_storage_size_in_tb")

    @_builtins.property
    @pulumi.getter(name="allocatedStorageSizeInTb")
    def allocated_storage_size_in_tb(self) -> _builtins.float:
        """
        The amount of storage currently allocated for the database tables and billed for, rounded up. When auto-scaling is not enabled, this value is equal to the `data_storage_size_in_tb` value. You can compare this value to the `actual_used_data_storage_size_in_tb` value to determine if a manual shrink operation is appropriate for your allocated storage.
        """
        return pulumi.get(self, "allocated_storage_size_in_tb")

    @_builtins.property
    @pulumi.getter(name="allowedIpAddresses")
    def allowed_ip_addresses(self) -> Sequence[_builtins.str]:
        """
        A list of IP addresses on the access control list.
        """
        return pulumi.get(self, "allowed_ip_addresses")

    @_builtins.property
    @pulumi.getter(name="autoScalingEnabled")
    def auto_scaling_enabled(self) -> _builtins.bool:
        """
        Whether auto-scaling is enabled for the Autonomous Database CPU core count.
        """
        return pulumi.get(self, "auto_scaling_enabled")

    @_builtins.property
    @pulumi.getter(name="autoScalingForStorageEnabled")
    def auto_scaling_for_storage_enabled(self) -> _builtins.bool:
        """
        Whether auto-scaling is enabled for the Autonomous Database storage.
        """
        return pulumi.get(self, "auto_scaling_for_storage_enabled")

    @_builtins.property
    @pulumi.getter(name="availableUpgradeVersions")
    def available_upgrade_versions(self) -> Sequence[_builtins.str]:
        """
        A list of Oracle Database versions available for a database upgrade. If there are no version upgrades available, this list is empty.
        """
        return pulumi.get(self, "available_upgrade_versions")

    @_builtins.property
    @pulumi.getter(name="backupRetentionPeriodInDays")
    def backup_retention_period_in_days(self) -> _builtins.int:
        """
        The backup retention period in days.
        """
        return pulumi.get(self, "backup_retention_period_in_days")

    @_builtins.property
    @pulumi.getter(name="characterSet")
    def character_set(self) -> _builtins.str:
        """
        The character set for the autonomous database.
        """
        return pulumi.get(self, "character_set")

    @_builtins.property
    @pulumi.getter(name="computeCount")
    def compute_count(self) -> _builtins.float:
        """
        The compute amount (CPUs) available to the database.
        """
        return pulumi.get(self, "compute_count")

    @_builtins.property
    @pulumi.getter(name="computeModel")
    def compute_model(self) -> _builtins.str:
        """
        The compute model of the Autonomous Database.
        """
        return pulumi.get(self, "compute_model")

    @_builtins.property
    @pulumi.getter(name="connectionStrings")
    def connection_strings(self) -> Sequence[_builtins.str]:
        """
        The connection string used to connect to the Autonomous Database.
        """
        return pulumi.get(self, "connection_strings")

    @_builtins.property
    @pulumi.getter(name="cpuCoreCount")
    def cpu_core_count(self) -> _builtins.int:
        """
        The number of CPU cores available to the database. When the ECPU is selected, the value for cpuCoreCount is 0.
        """
        return pulumi.get(self, "cpu_core_count")

    @_builtins.property
    @pulumi.getter(name="customerContacts")
    def customer_contacts(self) -> Sequence[_builtins.str]:
        """
        A list of Customer's contact email addresses.
        """
        return pulumi.get(self, "customer_contacts")

    @_builtins.property
    @pulumi.getter(name="dataStorageSizeInGb")
    def data_storage_size_in_gb(self) -> _builtins.int:
        """
        The quantity of data in the database in gigabytes.
        """
        return pulumi.get(self, "data_storage_size_in_gb")

    @_builtins.property
    @pulumi.getter(name="dataStorageSizeInTb")
    def data_storage_size_in_tb(self) -> _builtins.int:
        """
        The maximum storage that can be allocated for the database in terabytes.
        """
        return pulumi.get(self, "data_storage_size_in_tb")

    @_builtins.property
    @pulumi.getter(name="databaseVersion")
    def database_version(self) -> _builtins.str:
        """
        The Oracle Database version for Autonomous Database.
        """
        return pulumi.get(self, "database_version")

    @_builtins.property
    @pulumi.getter(name="databaseWorkload")
    def database_workload(self) -> _builtins.str:
        """
        The Autonomous Database workload type.
        """
        return pulumi.get(self, "database_workload")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        The display name for the Autonomous Database.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="failedDataRecoveryInSeconds")
    def failed_data_recovery_in_seconds(self) -> _builtins.int:
        """
        Indicates the number of seconds of data loss for Data Guard failover.
        """
        return pulumi.get(self, "failed_data_recovery_in_seconds")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="inMemoryAreaInGb")
    def in_memory_area_in_gb(self) -> _builtins.int:
        """
        The area assigned to In-Memory tables in Autonomous Database.
        """
        return pulumi.get(self, "in_memory_area_in_gb")

    @_builtins.property
    @pulumi.getter(name="licenseModel")
    def license_model(self) -> _builtins.str:
        """
        The Oracle license model that applied to the Oracle Autonomous Database.
        """
        return pulumi.get(self, "license_model")

    @_builtins.property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> _builtins.str:
        """
        Information about the current lifecycle state.
        """
        return pulumi.get(self, "lifecycle_details")

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> _builtins.str:
        """
        The current state of the backup.
        """
        return pulumi.get(self, "lifecycle_state")

    @_builtins.property
    @pulumi.getter(name="localAdgAutoFailoverMaxDataLossLimitInSeconds")
    def local_adg_auto_failover_max_data_loss_limit_in_seconds(self) -> _builtins.int:
        """
        Parameter that allows users to select an acceptable maximum data loss limit in seconds, up to which Automatic Failover will be triggered when necessary for a Local Autonomous Data Guard.
        """
        return pulumi.get(self, "local_adg_auto_failover_max_data_loss_limit_in_seconds")

    @_builtins.property
    @pulumi.getter(name="localDataGuardEnabled")
    def local_data_guard_enabled(self) -> _builtins.bool:
        """
        Indicates whether the Autonomous Database has local (in-region) Data Guard enabled. Not applicable to cross-region Autonomous Data Guard associations, or to Autonomous Databases using dedicated Exadata infrastructure or Exadata Cloud@Customer infrastructure.
        """
        return pulumi.get(self, "local_data_guard_enabled")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        The Azure Region where the autonomous database cloned from backup exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter(name="longTermBackupSchedules")
    def long_term_backup_schedules(self) -> Sequence['outputs.GetAutonomousDatabaseCloneFromBackupLongTermBackupScheduleResult']:
        """
        A `long_term_backup_schedule` block as defined below.
        """
        return pulumi.get(self, "long_term_backup_schedules")

    @_builtins.property
    @pulumi.getter(name="memoryPerOracleComputeUnitInGb")
    def memory_per_oracle_compute_unit_in_gb(self) -> _builtins.int:
        """
        The amount of memory in gigabytes per ECPU or OCPU.
        """
        return pulumi.get(self, "memory_per_oracle_compute_unit_in_gb")

    @_builtins.property
    @pulumi.getter(name="mtlsConnectionRequired")
    def mtls_connection_required(self) -> _builtins.bool:
        """
        Specifies if the Autonomous Database requires mTLS connections.
        """
        return pulumi.get(self, "mtls_connection_required")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nationalCharacterSet")
    def national_character_set(self) -> _builtins.str:
        """
        The national character set for the autonomous database.
        """
        return pulumi.get(self, "national_character_set")

    @_builtins.property
    @pulumi.getter(name="nextLongTermBackupTimestamp")
    def next_long_term_backup_timestamp(self) -> _builtins.str:
        return pulumi.get(self, "next_long_term_backup_timestamp")

    @_builtins.property
    @pulumi.getter(name="ociUrl")
    def oci_url(self) -> _builtins.str:
        """
        The URL of the resource in the OCI console.
        """
        return pulumi.get(self, "oci_url")

    @_builtins.property
    @pulumi.getter
    def ocid(self) -> _builtins.str:
        """
        The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the autonomous database.
        """
        return pulumi.get(self, "ocid")

    @_builtins.property
    @pulumi.getter(name="peerDatabaseIds")
    def peer_database_ids(self) -> Sequence[_builtins.str]:
        """
        The list of [OCIDs](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of standby databases located in Autonomous Data Guard remote regions that are associated with the source database. Note that for Autonomous Database Serverless instances, standby databases located in the same region as the source primary database do not have OCIDs.
        """
        return pulumi.get(self, "peer_database_ids")

    @_builtins.property
    @pulumi.getter
    def preview(self) -> _builtins.bool:
        """
        Indicates if the Autonomous Database version is a preview version.
        """
        return pulumi.get(self, "preview")

    @_builtins.property
    @pulumi.getter(name="previewVersionWithServiceTermsAccepted")
    def preview_version_with_service_terms_accepted(self) -> _builtins.bool:
        """
        Indicates if the Autonomous Database version is a preview version with service terms accepted.
        """
        return pulumi.get(self, "preview_version_with_service_terms_accepted")

    @_builtins.property
    @pulumi.getter(name="privateEndpointIp")
    def private_endpoint_ip(self) -> _builtins.str:
        """
        The private endpoint IP address for the resource.
        """
        return pulumi.get(self, "private_endpoint_ip")

    @_builtins.property
    @pulumi.getter(name="privateEndpointLabel")
    def private_endpoint_label(self) -> _builtins.str:
        """
        The private endpoint label for the resource.
        """
        return pulumi.get(self, "private_endpoint_label")

    @_builtins.property
    @pulumi.getter(name="privateEndpointUrl")
    def private_endpoint_url(self) -> _builtins.str:
        """
        The private endpoint for the resource.
        """
        return pulumi.get(self, "private_endpoint_url")

    @_builtins.property
    @pulumi.getter(name="provisionableCpuses")
    def provisionable_cpuses(self) -> Sequence[_builtins.int]:
        """
        An array of CPU values that an Autonomous Database can be scaled to.
        """
        return pulumi.get(self, "provisionable_cpuses")

    @_builtins.property
    @pulumi.getter(name="remoteDataGuardEnabled")
    def remote_data_guard_enabled(self) -> _builtins.bool:
        """
        Indicates whether the Autonomous Database has Cross Region Data Guard enabled. Not applicable to Autonomous Databases using dedicated Exadata infrastructure or Exadata Cloud@Customer infrastructure.
        """
        return pulumi.get(self, "remote_data_guard_enabled")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="serviceConsoleUrl")
    def service_console_url(self) -> _builtins.str:
        """
        The URL of the Service Console for the Autonomous Database.
        """
        return pulumi.get(self, "service_console_url")

    @_builtins.property
    @pulumi.getter(name="sourceAutonomousDatabaseId")
    def source_autonomous_database_id(self) -> _builtins.str:
        """
        The ID of the source Autonomous Database from which this clone was created.
        """
        return pulumi.get(self, "source_autonomous_database_id")

    @_builtins.property
    @pulumi.getter(name="sqlWebDeveloperUrl")
    def sql_web_developer_url(self) -> _builtins.str:
        """
        The URL of the SQL web developer portal.
        """
        return pulumi.get(self, "sql_web_developer_url")

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> _builtins.str:
        """
        The ID to an Azure Resource Manager subnet the resource is associated with.
        """
        return pulumi.get(self, "subnet_id")

    @_builtins.property
    @pulumi.getter(name="supportedRegionsToCloneTos")
    def supported_regions_to_clone_tos(self) -> Sequence[_builtins.str]:
        """
        The list of regions that support the creation of an Autonomous Database clone or an Autonomous Data Guard standby database.
        """
        return pulumi.get(self, "supported_regions_to_clone_tos")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        A mapping of tags assigned to the autonomous database clone from backup.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="timeCreatedInUtc")
    def time_created_in_utc(self) -> _builtins.str:
        """
        The timestamp the Autonomous Database was created.
        """
        return pulumi.get(self, "time_created_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeDataGuardRoleChangedInUtc")
    def time_data_guard_role_changed_in_utc(self) -> _builtins.str:
        """
        The timestamp the Autonomous Data Guard role was switched for the Autonomous Database. For databases that have standbys in both the primary Data Guard region and a remote Data Guard standby region, this is the latest timestamp of either the database using the "primary" role in the primary Data Guard region, or database located in the remote Data Guard standby region.
        """
        return pulumi.get(self, "time_data_guard_role_changed_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeDeletionOfFreeAutonomousDatabaseInUtc")
    def time_deletion_of_free_autonomous_database_in_utc(self) -> _builtins.str:
        """
        The timestamp the Always Free database will be automatically deleted because of inactivity. If the database is in the STOPPED state and without activity until this time, it will be deleted.
        """
        return pulumi.get(self, "time_deletion_of_free_autonomous_database_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeLocalDataGuardEnabledInUtc")
    def time_local_data_guard_enabled_in_utc(self) -> _builtins.str:
        """
        The timestamp that Autonomous Data Guard was enabled for an Autonomous Database where the standby was provisioned in the same region as the primary database.
        """
        return pulumi.get(self, "time_local_data_guard_enabled_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeMaintenanceBeginInUtc")
    def time_maintenance_begin_in_utc(self) -> _builtins.str:
        """
        The timestamp when maintenance will begin.
        """
        return pulumi.get(self, "time_maintenance_begin_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeMaintenanceEndInUtc")
    def time_maintenance_end_in_utc(self) -> _builtins.str:
        """
        The timestamp when maintenance will end.
        """
        return pulumi.get(self, "time_maintenance_end_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeOfLastFailoverInUtc")
    def time_of_last_failover_in_utc(self) -> _builtins.str:
        """
        The timestamp of the last failover operation.
        """
        return pulumi.get(self, "time_of_last_failover_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeOfLastRefreshInUtc")
    def time_of_last_refresh_in_utc(self) -> _builtins.str:
        """
        The timestamp when the last refresh happened.
        """
        return pulumi.get(self, "time_of_last_refresh_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeOfLastRefreshPointInUtc")
    def time_of_last_refresh_point_in_utc(self) -> _builtins.str:
        """
        The refresh point timestamp (UTC). The refresh point is the time to which the database was most recently refreshed. Data created after the refresh point is not included in the refresh.
        """
        return pulumi.get(self, "time_of_last_refresh_point_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeOfLastSwitchoverInUtc")
    def time_of_last_switchover_in_utc(self) -> _builtins.str:
        """
        The timestamp of the last switchover operation for the Autonomous Database.
        """
        return pulumi.get(self, "time_of_last_switchover_in_utc")

    @_builtins.property
    @pulumi.getter(name="timeReclamationOfFreeAutonomousDatabaseInUtc")
    def time_reclamation_of_free_autonomous_database_in_utc(self) -> _builtins.str:
        """
        The timestamp the Always Free database will be stopped because of inactivity. If this time is reached without any database activity, the database will automatically be put into the STOPPED state.
        """
        return pulumi.get(self, "time_reclamation_of_free_autonomous_database_in_utc")

    @_builtins.property
    @pulumi.getter(name="usedDataStorageSizeInGb")
    def used_data_storage_size_in_gb(self) -> _builtins.int:
        """
        The storage space consumed by Autonomous Database in gigabytes.
        """
        return pulumi.get(self, "used_data_storage_size_in_gb")

    @_builtins.property
    @pulumi.getter(name="usedDataStorageSizeInTb")
    def used_data_storage_size_in_tb(self) -> _builtins.int:
        """
        The amount of storage that has been used, in terabytes.
        """
        return pulumi.get(self, "used_data_storage_size_in_tb")

    @_builtins.property
    @pulumi.getter(name="virtualNetworkId")
    def virtual_network_id(self) -> _builtins.str:
        """
        The ID to an Azure Resource Manager virtual network resource.
        """
        return pulumi.get(self, "virtual_network_id")


class AwaitableGetAutonomousDatabaseCloneFromBackupResult(GetAutonomousDatabaseCloneFromBackupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAutonomousDatabaseCloneFromBackupResult(
            actual_used_data_storage_size_in_tb=self.actual_used_data_storage_size_in_tb,
            allocated_storage_size_in_tb=self.allocated_storage_size_in_tb,
            allowed_ip_addresses=self.allowed_ip_addresses,
            auto_scaling_enabled=self.auto_scaling_enabled,
            auto_scaling_for_storage_enabled=self.auto_scaling_for_storage_enabled,
            available_upgrade_versions=self.available_upgrade_versions,
            backup_retention_period_in_days=self.backup_retention_period_in_days,
            character_set=self.character_set,
            compute_count=self.compute_count,
            compute_model=self.compute_model,
            connection_strings=self.connection_strings,
            cpu_core_count=self.cpu_core_count,
            customer_contacts=self.customer_contacts,
            data_storage_size_in_gb=self.data_storage_size_in_gb,
            data_storage_size_in_tb=self.data_storage_size_in_tb,
            database_version=self.database_version,
            database_workload=self.database_workload,
            display_name=self.display_name,
            failed_data_recovery_in_seconds=self.failed_data_recovery_in_seconds,
            id=self.id,
            in_memory_area_in_gb=self.in_memory_area_in_gb,
            license_model=self.license_model,
            lifecycle_details=self.lifecycle_details,
            lifecycle_state=self.lifecycle_state,
            local_adg_auto_failover_max_data_loss_limit_in_seconds=self.local_adg_auto_failover_max_data_loss_limit_in_seconds,
            local_data_guard_enabled=self.local_data_guard_enabled,
            location=self.location,
            long_term_backup_schedules=self.long_term_backup_schedules,
            memory_per_oracle_compute_unit_in_gb=self.memory_per_oracle_compute_unit_in_gb,
            mtls_connection_required=self.mtls_connection_required,
            name=self.name,
            national_character_set=self.national_character_set,
            next_long_term_backup_timestamp=self.next_long_term_backup_timestamp,
            oci_url=self.oci_url,
            ocid=self.ocid,
            peer_database_ids=self.peer_database_ids,
            preview=self.preview,
            preview_version_with_service_terms_accepted=self.preview_version_with_service_terms_accepted,
            private_endpoint_ip=self.private_endpoint_ip,
            private_endpoint_label=self.private_endpoint_label,
            private_endpoint_url=self.private_endpoint_url,
            provisionable_cpuses=self.provisionable_cpuses,
            remote_data_guard_enabled=self.remote_data_guard_enabled,
            resource_group_name=self.resource_group_name,
            service_console_url=self.service_console_url,
            source_autonomous_database_id=self.source_autonomous_database_id,
            sql_web_developer_url=self.sql_web_developer_url,
            subnet_id=self.subnet_id,
            supported_regions_to_clone_tos=self.supported_regions_to_clone_tos,
            tags=self.tags,
            time_created_in_utc=self.time_created_in_utc,
            time_data_guard_role_changed_in_utc=self.time_data_guard_role_changed_in_utc,
            time_deletion_of_free_autonomous_database_in_utc=self.time_deletion_of_free_autonomous_database_in_utc,
            time_local_data_guard_enabled_in_utc=self.time_local_data_guard_enabled_in_utc,
            time_maintenance_begin_in_utc=self.time_maintenance_begin_in_utc,
            time_maintenance_end_in_utc=self.time_maintenance_end_in_utc,
            time_of_last_failover_in_utc=self.time_of_last_failover_in_utc,
            time_of_last_refresh_in_utc=self.time_of_last_refresh_in_utc,
            time_of_last_refresh_point_in_utc=self.time_of_last_refresh_point_in_utc,
            time_of_last_switchover_in_utc=self.time_of_last_switchover_in_utc,
            time_reclamation_of_free_autonomous_database_in_utc=self.time_reclamation_of_free_autonomous_database_in_utc,
            used_data_storage_size_in_gb=self.used_data_storage_size_in_gb,
            used_data_storage_size_in_tb=self.used_data_storage_size_in_tb,
            virtual_network_id=self.virtual_network_id)


def get_autonomous_database_clone_from_backup(name: Optional[_builtins.str] = None,
                                              resource_group_name: Optional[_builtins.str] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAutonomousDatabaseCloneFromBackupResult:
    """
    Use this data source to access information about an existing autonomous database clone from backup.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_autonomous_database_clone_from_backup(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.str name: The name of this autonomous database clone from backup.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Autonomous Database Clone exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:oracle/getAutonomousDatabaseCloneFromBackup:getAutonomousDatabaseCloneFromBackup', __args__, opts=opts, typ=GetAutonomousDatabaseCloneFromBackupResult).value

    return AwaitableGetAutonomousDatabaseCloneFromBackupResult(
        actual_used_data_storage_size_in_tb=pulumi.get(__ret__, 'actual_used_data_storage_size_in_tb'),
        allocated_storage_size_in_tb=pulumi.get(__ret__, 'allocated_storage_size_in_tb'),
        allowed_ip_addresses=pulumi.get(__ret__, 'allowed_ip_addresses'),
        auto_scaling_enabled=pulumi.get(__ret__, 'auto_scaling_enabled'),
        auto_scaling_for_storage_enabled=pulumi.get(__ret__, 'auto_scaling_for_storage_enabled'),
        available_upgrade_versions=pulumi.get(__ret__, 'available_upgrade_versions'),
        backup_retention_period_in_days=pulumi.get(__ret__, 'backup_retention_period_in_days'),
        character_set=pulumi.get(__ret__, 'character_set'),
        compute_count=pulumi.get(__ret__, 'compute_count'),
        compute_model=pulumi.get(__ret__, 'compute_model'),
        connection_strings=pulumi.get(__ret__, 'connection_strings'),
        cpu_core_count=pulumi.get(__ret__, 'cpu_core_count'),
        customer_contacts=pulumi.get(__ret__, 'customer_contacts'),
        data_storage_size_in_gb=pulumi.get(__ret__, 'data_storage_size_in_gb'),
        data_storage_size_in_tb=pulumi.get(__ret__, 'data_storage_size_in_tb'),
        database_version=pulumi.get(__ret__, 'database_version'),
        database_workload=pulumi.get(__ret__, 'database_workload'),
        display_name=pulumi.get(__ret__, 'display_name'),
        failed_data_recovery_in_seconds=pulumi.get(__ret__, 'failed_data_recovery_in_seconds'),
        id=pulumi.get(__ret__, 'id'),
        in_memory_area_in_gb=pulumi.get(__ret__, 'in_memory_area_in_gb'),
        license_model=pulumi.get(__ret__, 'license_model'),
        lifecycle_details=pulumi.get(__ret__, 'lifecycle_details'),
        lifecycle_state=pulumi.get(__ret__, 'lifecycle_state'),
        local_adg_auto_failover_max_data_loss_limit_in_seconds=pulumi.get(__ret__, 'local_adg_auto_failover_max_data_loss_limit_in_seconds'),
        local_data_guard_enabled=pulumi.get(__ret__, 'local_data_guard_enabled'),
        location=pulumi.get(__ret__, 'location'),
        long_term_backup_schedules=pulumi.get(__ret__, 'long_term_backup_schedules'),
        memory_per_oracle_compute_unit_in_gb=pulumi.get(__ret__, 'memory_per_oracle_compute_unit_in_gb'),
        mtls_connection_required=pulumi.get(__ret__, 'mtls_connection_required'),
        name=pulumi.get(__ret__, 'name'),
        national_character_set=pulumi.get(__ret__, 'national_character_set'),
        next_long_term_backup_timestamp=pulumi.get(__ret__, 'next_long_term_backup_timestamp'),
        oci_url=pulumi.get(__ret__, 'oci_url'),
        ocid=pulumi.get(__ret__, 'ocid'),
        peer_database_ids=pulumi.get(__ret__, 'peer_database_ids'),
        preview=pulumi.get(__ret__, 'preview'),
        preview_version_with_service_terms_accepted=pulumi.get(__ret__, 'preview_version_with_service_terms_accepted'),
        private_endpoint_ip=pulumi.get(__ret__, 'private_endpoint_ip'),
        private_endpoint_label=pulumi.get(__ret__, 'private_endpoint_label'),
        private_endpoint_url=pulumi.get(__ret__, 'private_endpoint_url'),
        provisionable_cpuses=pulumi.get(__ret__, 'provisionable_cpuses'),
        remote_data_guard_enabled=pulumi.get(__ret__, 'remote_data_guard_enabled'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        service_console_url=pulumi.get(__ret__, 'service_console_url'),
        source_autonomous_database_id=pulumi.get(__ret__, 'source_autonomous_database_id'),
        sql_web_developer_url=pulumi.get(__ret__, 'sql_web_developer_url'),
        subnet_id=pulumi.get(__ret__, 'subnet_id'),
        supported_regions_to_clone_tos=pulumi.get(__ret__, 'supported_regions_to_clone_tos'),
        tags=pulumi.get(__ret__, 'tags'),
        time_created_in_utc=pulumi.get(__ret__, 'time_created_in_utc'),
        time_data_guard_role_changed_in_utc=pulumi.get(__ret__, 'time_data_guard_role_changed_in_utc'),
        time_deletion_of_free_autonomous_database_in_utc=pulumi.get(__ret__, 'time_deletion_of_free_autonomous_database_in_utc'),
        time_local_data_guard_enabled_in_utc=pulumi.get(__ret__, 'time_local_data_guard_enabled_in_utc'),
        time_maintenance_begin_in_utc=pulumi.get(__ret__, 'time_maintenance_begin_in_utc'),
        time_maintenance_end_in_utc=pulumi.get(__ret__, 'time_maintenance_end_in_utc'),
        time_of_last_failover_in_utc=pulumi.get(__ret__, 'time_of_last_failover_in_utc'),
        time_of_last_refresh_in_utc=pulumi.get(__ret__, 'time_of_last_refresh_in_utc'),
        time_of_last_refresh_point_in_utc=pulumi.get(__ret__, 'time_of_last_refresh_point_in_utc'),
        time_of_last_switchover_in_utc=pulumi.get(__ret__, 'time_of_last_switchover_in_utc'),
        time_reclamation_of_free_autonomous_database_in_utc=pulumi.get(__ret__, 'time_reclamation_of_free_autonomous_database_in_utc'),
        used_data_storage_size_in_gb=pulumi.get(__ret__, 'used_data_storage_size_in_gb'),
        used_data_storage_size_in_tb=pulumi.get(__ret__, 'used_data_storage_size_in_tb'),
        virtual_network_id=pulumi.get(__ret__, 'virtual_network_id'))
def get_autonomous_database_clone_from_backup_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                                     resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAutonomousDatabaseCloneFromBackupResult]:
    """
    Use this data source to access information about an existing autonomous database clone from backup.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_autonomous_database_clone_from_backup(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.str name: The name of this autonomous database clone from backup.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Autonomous Database Clone exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:oracle/getAutonomousDatabaseCloneFromBackup:getAutonomousDatabaseCloneFromBackup', __args__, opts=opts, typ=GetAutonomousDatabaseCloneFromBackupResult)
    return __ret__.apply(lambda __response__: GetAutonomousDatabaseCloneFromBackupResult(
        actual_used_data_storage_size_in_tb=pulumi.get(__response__, 'actual_used_data_storage_size_in_tb'),
        allocated_storage_size_in_tb=pulumi.get(__response__, 'allocated_storage_size_in_tb'),
        allowed_ip_addresses=pulumi.get(__response__, 'allowed_ip_addresses'),
        auto_scaling_enabled=pulumi.get(__response__, 'auto_scaling_enabled'),
        auto_scaling_for_storage_enabled=pulumi.get(__response__, 'auto_scaling_for_storage_enabled'),
        available_upgrade_versions=pulumi.get(__response__, 'available_upgrade_versions'),
        backup_retention_period_in_days=pulumi.get(__response__, 'backup_retention_period_in_days'),
        character_set=pulumi.get(__response__, 'character_set'),
        compute_count=pulumi.get(__response__, 'compute_count'),
        compute_model=pulumi.get(__response__, 'compute_model'),
        connection_strings=pulumi.get(__response__, 'connection_strings'),
        cpu_core_count=pulumi.get(__response__, 'cpu_core_count'),
        customer_contacts=pulumi.get(__response__, 'customer_contacts'),
        data_storage_size_in_gb=pulumi.get(__response__, 'data_storage_size_in_gb'),
        data_storage_size_in_tb=pulumi.get(__response__, 'data_storage_size_in_tb'),
        database_version=pulumi.get(__response__, 'database_version'),
        database_workload=pulumi.get(__response__, 'database_workload'),
        display_name=pulumi.get(__response__, 'display_name'),
        failed_data_recovery_in_seconds=pulumi.get(__response__, 'failed_data_recovery_in_seconds'),
        id=pulumi.get(__response__, 'id'),
        in_memory_area_in_gb=pulumi.get(__response__, 'in_memory_area_in_gb'),
        license_model=pulumi.get(__response__, 'license_model'),
        lifecycle_details=pulumi.get(__response__, 'lifecycle_details'),
        lifecycle_state=pulumi.get(__response__, 'lifecycle_state'),
        local_adg_auto_failover_max_data_loss_limit_in_seconds=pulumi.get(__response__, 'local_adg_auto_failover_max_data_loss_limit_in_seconds'),
        local_data_guard_enabled=pulumi.get(__response__, 'local_data_guard_enabled'),
        location=pulumi.get(__response__, 'location'),
        long_term_backup_schedules=pulumi.get(__response__, 'long_term_backup_schedules'),
        memory_per_oracle_compute_unit_in_gb=pulumi.get(__response__, 'memory_per_oracle_compute_unit_in_gb'),
        mtls_connection_required=pulumi.get(__response__, 'mtls_connection_required'),
        name=pulumi.get(__response__, 'name'),
        national_character_set=pulumi.get(__response__, 'national_character_set'),
        next_long_term_backup_timestamp=pulumi.get(__response__, 'next_long_term_backup_timestamp'),
        oci_url=pulumi.get(__response__, 'oci_url'),
        ocid=pulumi.get(__response__, 'ocid'),
        peer_database_ids=pulumi.get(__response__, 'peer_database_ids'),
        preview=pulumi.get(__response__, 'preview'),
        preview_version_with_service_terms_accepted=pulumi.get(__response__, 'preview_version_with_service_terms_accepted'),
        private_endpoint_ip=pulumi.get(__response__, 'private_endpoint_ip'),
        private_endpoint_label=pulumi.get(__response__, 'private_endpoint_label'),
        private_endpoint_url=pulumi.get(__response__, 'private_endpoint_url'),
        provisionable_cpuses=pulumi.get(__response__, 'provisionable_cpuses'),
        remote_data_guard_enabled=pulumi.get(__response__, 'remote_data_guard_enabled'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        service_console_url=pulumi.get(__response__, 'service_console_url'),
        source_autonomous_database_id=pulumi.get(__response__, 'source_autonomous_database_id'),
        sql_web_developer_url=pulumi.get(__response__, 'sql_web_developer_url'),
        subnet_id=pulumi.get(__response__, 'subnet_id'),
        supported_regions_to_clone_tos=pulumi.get(__response__, 'supported_regions_to_clone_tos'),
        tags=pulumi.get(__response__, 'tags'),
        time_created_in_utc=pulumi.get(__response__, 'time_created_in_utc'),
        time_data_guard_role_changed_in_utc=pulumi.get(__response__, 'time_data_guard_role_changed_in_utc'),
        time_deletion_of_free_autonomous_database_in_utc=pulumi.get(__response__, 'time_deletion_of_free_autonomous_database_in_utc'),
        time_local_data_guard_enabled_in_utc=pulumi.get(__response__, 'time_local_data_guard_enabled_in_utc'),
        time_maintenance_begin_in_utc=pulumi.get(__response__, 'time_maintenance_begin_in_utc'),
        time_maintenance_end_in_utc=pulumi.get(__response__, 'time_maintenance_end_in_utc'),
        time_of_last_failover_in_utc=pulumi.get(__response__, 'time_of_last_failover_in_utc'),
        time_of_last_refresh_in_utc=pulumi.get(__response__, 'time_of_last_refresh_in_utc'),
        time_of_last_refresh_point_in_utc=pulumi.get(__response__, 'time_of_last_refresh_point_in_utc'),
        time_of_last_switchover_in_utc=pulumi.get(__response__, 'time_of_last_switchover_in_utc'),
        time_reclamation_of_free_autonomous_database_in_utc=pulumi.get(__response__, 'time_reclamation_of_free_autonomous_database_in_utc'),
        used_data_storage_size_in_gb=pulumi.get(__response__, 'used_data_storage_size_in_gb'),
        used_data_storage_size_in_tb=pulumi.get(__response__, 'used_data_storage_size_in_tb'),
        virtual_network_id=pulumi.get(__response__, 'virtual_network_id')))
