# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceNamedValueArgs', 'WorkspaceNamedValue']

@pulumi.input_type
class WorkspaceNamedValueArgs:
    def __init__(__self__, *,
                 api_management_workspace_id: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_from_key_vault: Optional[pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs']] = None):
        """
        The set of arguments for constructing a WorkspaceNamedValue resource.

        :param pulumi.Input[_builtins.str] api_management_workspace_id: The ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] display_name: The display name of this API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] name: The name of the API Management Workspace Named Value. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.bool] secret: Specifies whether the API Management Workspace Named Value is secret. Defaults to `false`.
               
               > **Note:** Setting the field `secret` to `true` does not make this field sensitive in Terraform, instead it marks the value as secret and encrypts the value in Azure.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to be applied to the API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] value: The value of this API Management Workspace Named Value.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified.
        :param pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs'] value_from_key_vault: A `value_from_key_vault` block as defined below.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified. If `value_from_key_vault` is specified, `secret` must also be set to `true`.
        """
        pulumi.set(__self__, "api_management_workspace_id", api_management_workspace_id)
        pulumi.set(__self__, "display_name", display_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_from_key_vault is not None:
            pulumi.set(__self__, "value_from_key_vault", value_from_key_vault)

    @_builtins.property
    @pulumi.getter(name="apiManagementWorkspaceId")
    def api_management_workspace_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the API Management Workspace. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_workspace_id")

    @api_management_workspace_id.setter
    def api_management_workspace_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "api_management_workspace_id", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The display name of this API Management Workspace Named Value.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API Management Workspace Named Value. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether the API Management Workspace Named Value is secret. Defaults to `false`.

        > **Note:** Setting the field `secret` to `true` does not make this field sensitive in Terraform, instead it marks the value as secret and encrypts the value in Azure.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of tags to be applied to the API Management Workspace Named Value.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of this API Management Workspace Named Value.

        > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="valueFromKeyVault")
    def value_from_key_vault(self) -> Optional[pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs']]:
        """
        A `value_from_key_vault` block as defined below.

        > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified. If `value_from_key_vault` is specified, `secret` must also be set to `true`.
        """
        return pulumi.get(self, "value_from_key_vault")

    @value_from_key_vault.setter
    def value_from_key_vault(self, value: Optional[pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs']]):
        pulumi.set(self, "value_from_key_vault", value)


@pulumi.input_type
class _WorkspaceNamedValueState:
    def __init__(__self__, *,
                 api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_from_key_vault: Optional[pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs']] = None):
        """
        Input properties used for looking up and filtering WorkspaceNamedValue resources.

        :param pulumi.Input[_builtins.str] api_management_workspace_id: The ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] display_name: The display name of this API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] name: The name of the API Management Workspace Named Value. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.bool] secret: Specifies whether the API Management Workspace Named Value is secret. Defaults to `false`.
               
               > **Note:** Setting the field `secret` to `true` does not make this field sensitive in Terraform, instead it marks the value as secret and encrypts the value in Azure.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to be applied to the API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] value: The value of this API Management Workspace Named Value.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified.
        :param pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs'] value_from_key_vault: A `value_from_key_vault` block as defined below.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified. If `value_from_key_vault` is specified, `secret` must also be set to `true`.
        """
        if api_management_workspace_id is not None:
            pulumi.set(__self__, "api_management_workspace_id", api_management_workspace_id)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_from_key_vault is not None:
            pulumi.set(__self__, "value_from_key_vault", value_from_key_vault)

    @_builtins.property
    @pulumi.getter(name="apiManagementWorkspaceId")
    def api_management_workspace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the API Management Workspace. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_workspace_id")

    @api_management_workspace_id.setter
    def api_management_workspace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_management_workspace_id", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of this API Management Workspace Named Value.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API Management Workspace Named Value. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether the API Management Workspace Named Value is secret. Defaults to `false`.

        > **Note:** Setting the field `secret` to `true` does not make this field sensitive in Terraform, instead it marks the value as secret and encrypts the value in Azure.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of tags to be applied to the API Management Workspace Named Value.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of this API Management Workspace Named Value.

        > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="valueFromKeyVault")
    def value_from_key_vault(self) -> Optional[pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs']]:
        """
        A `value_from_key_vault` block as defined below.

        > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified. If `value_from_key_vault` is specified, `secret` must also be set to `true`.
        """
        return pulumi.get(self, "value_from_key_vault")

    @value_from_key_vault.setter
    def value_from_key_vault(self, value: Optional[pulumi.Input['WorkspaceNamedValueValueFromKeyVaultArgs']]):
        pulumi.set(self, "value_from_key_vault", value)


@pulumi.type_token("azure:apimanagement/workspaceNamedValue:WorkspaceNamedValue")
class WorkspaceNamedValue(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_from_key_vault: Optional[pulumi.Input[Union['WorkspaceNamedValueValueFromKeyVaultArgs', 'WorkspaceNamedValueValueFromKeyVaultArgsDict']]] = None,
                 __props__=None):
        """
        Manages an API Management Workspace Named Value.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_service = azure.apimanagement.Service("example",
            name="example-apim",
            location=example.location,
            resource_group_name=example.name,
            publisher_name="My Company",
            publisher_email="company@terraform.io",
            sku_name="Premium_1")
        example_workspace = azure.apimanagement.Workspace("example",
            name="example-workspace",
            api_management_id=example_service.id,
            display_name="ExampleWorkspace")
        example_workspace_named_value = azure.apimanagement.WorkspaceNamedValue("example",
            name="example-named-value",
            api_management_workspace_id=example_workspace.id,
            display_name="ExampleProperty",
            value="Example Value",
            tags=[
                "tag1",
                "tag2",
                "tag3",
            ])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ApiManagement` - 2024-05-01

        ## Import

        API Management Workspace Named Values can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/workspaceNamedValue:WorkspaceNamedValue example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/service/service1/workspaces/workspace1/namedValues/namedValue1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_management_workspace_id: The ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] display_name: The display name of this API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] name: The name of the API Management Workspace Named Value. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.bool] secret: Specifies whether the API Management Workspace Named Value is secret. Defaults to `false`.
               
               > **Note:** Setting the field `secret` to `true` does not make this field sensitive in Terraform, instead it marks the value as secret and encrypts the value in Azure.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to be applied to the API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] value: The value of this API Management Workspace Named Value.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified.
        :param pulumi.Input[Union['WorkspaceNamedValueValueFromKeyVaultArgs', 'WorkspaceNamedValueValueFromKeyVaultArgsDict']] value_from_key_vault: A `value_from_key_vault` block as defined below.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified. If `value_from_key_vault` is specified, `secret` must also be set to `true`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkspaceNamedValueArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an API Management Workspace Named Value.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_service = azure.apimanagement.Service("example",
            name="example-apim",
            location=example.location,
            resource_group_name=example.name,
            publisher_name="My Company",
            publisher_email="company@terraform.io",
            sku_name="Premium_1")
        example_workspace = azure.apimanagement.Workspace("example",
            name="example-workspace",
            api_management_id=example_service.id,
            display_name="ExampleWorkspace")
        example_workspace_named_value = azure.apimanagement.WorkspaceNamedValue("example",
            name="example-named-value",
            api_management_workspace_id=example_workspace.id,
            display_name="ExampleProperty",
            value="Example Value",
            tags=[
                "tag1",
                "tag2",
                "tag3",
            ])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ApiManagement` - 2024-05-01

        ## Import

        API Management Workspace Named Values can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/workspaceNamedValue:WorkspaceNamedValue example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/service/service1/workspaces/workspace1/namedValues/namedValue1
        ```


        :param str resource_name: The name of the resource.
        :param WorkspaceNamedValueArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceNamedValueArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret: Optional[pulumi.Input[_builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_from_key_vault: Optional[pulumi.Input[Union['WorkspaceNamedValueValueFromKeyVaultArgs', 'WorkspaceNamedValueValueFromKeyVaultArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceNamedValueArgs.__new__(WorkspaceNamedValueArgs)

            if api_management_workspace_id is None and not opts.urn:
                raise TypeError("Missing required property 'api_management_workspace_id'")
            __props__.__dict__["api_management_workspace_id"] = api_management_workspace_id
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["name"] = name
            __props__.__dict__["secret"] = secret
            __props__.__dict__["tags"] = tags
            __props__.__dict__["value"] = None if value is None else pulumi.Output.secret(value)
            __props__.__dict__["value_from_key_vault"] = value_from_key_vault
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(WorkspaceNamedValue, __self__).__init__(
            'azure:apimanagement/workspaceNamedValue:WorkspaceNamedValue',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_management_workspace_id: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            secret: Optional[pulumi.Input[_builtins.bool]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            value_from_key_vault: Optional[pulumi.Input[Union['WorkspaceNamedValueValueFromKeyVaultArgs', 'WorkspaceNamedValueValueFromKeyVaultArgsDict']]] = None) -> 'WorkspaceNamedValue':
        """
        Get an existing WorkspaceNamedValue resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_management_workspace_id: The ID of the API Management Workspace. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] display_name: The display name of this API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] name: The name of the API Management Workspace Named Value. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.bool] secret: Specifies whether the API Management Workspace Named Value is secret. Defaults to `false`.
               
               > **Note:** Setting the field `secret` to `true` does not make this field sensitive in Terraform, instead it marks the value as secret and encrypts the value in Azure.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: A list of tags to be applied to the API Management Workspace Named Value.
        :param pulumi.Input[_builtins.str] value: The value of this API Management Workspace Named Value.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified.
        :param pulumi.Input[Union['WorkspaceNamedValueValueFromKeyVaultArgs', 'WorkspaceNamedValueValueFromKeyVaultArgsDict']] value_from_key_vault: A `value_from_key_vault` block as defined below.
               
               > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified. If `value_from_key_vault` is specified, `secret` must also be set to `true`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceNamedValueState.__new__(_WorkspaceNamedValueState)

        __props__.__dict__["api_management_workspace_id"] = api_management_workspace_id
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["name"] = name
        __props__.__dict__["secret"] = secret
        __props__.__dict__["tags"] = tags
        __props__.__dict__["value"] = value
        __props__.__dict__["value_from_key_vault"] = value_from_key_vault
        return WorkspaceNamedValue(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiManagementWorkspaceId")
    def api_management_workspace_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the API Management Workspace. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_workspace_id")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of this API Management Workspace Named Value.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the API Management Workspace Named Value. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Specifies whether the API Management Workspace Named Value is secret. Defaults to `false`.

        > **Note:** Setting the field `secret` to `true` does not make this field sensitive in Terraform, instead it marks the value as secret and encrypts the value in Azure.
        """
        return pulumi.get(self, "secret")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of tags to be applied to the API Management Workspace Named Value.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The value of this API Management Workspace Named Value.

        > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="valueFromKeyVault")
    def value_from_key_vault(self) -> pulumi.Output[Optional['outputs.WorkspaceNamedValueValueFromKeyVault']]:
        """
        A `value_from_key_vault` block as defined below.

        > **Note:** Exactly one of `value` or `value_from_key_vault` must be specified. If `value_from_key_vault` is specified, `secret` must also be set to `true`.
        """
        return pulumi.get(self, "value_from_key_vault")

