# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PortalDashboardArgs', 'PortalDashboard']

@pulumi.input_type
class PortalDashboardArgs:
    def __init__(__self__, *,
                 dashboard_properties: pulumi.Input[_builtins.str],
                 resource_group_name: pulumi.Input[_builtins.str],
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a PortalDashboard resource.

        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "dashboard_properties", dashboard_properties)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="dashboardProperties")
    def dashboard_properties(self) -> pulumi.Input[_builtins.str]:
        """
        JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        """
        return pulumi.get(self, "dashboard_properties")

    @dashboard_properties.setter
    def dashboard_properties(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "dashboard_properties", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.

        > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _PortalDashboardState:
    def __init__(__self__, *,
                 dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering PortalDashboard resources.

        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        if dashboard_properties is not None:
            pulumi.set(__self__, "dashboard_properties", dashboard_properties)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="dashboardProperties")
    def dashboard_properties(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        """
        return pulumi.get(self, "dashboard_properties")

    @dashboard_properties.setter
    def dashboard_properties(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dashboard_properties", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.

        > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("azure:portal/portalDashboard:PortalDashboard")
class PortalDashboard(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages a shared dashboard in the Azure Portal.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        config = pulumi.Config()
        # Content for the MD tile
        md_content = config.get("mdContent")
        if md_content is None:
            md_content = "# Hello all :)"
        # Link to a video
        video_link = config.get("videoLink")
        if video_link is None:
            video_link = "https://www.youtube.com/watch?v=......"
        current = azure.core.get_subscription()
        example = azure.core.ResourceGroup("example",
            name="mygroup",
            location="West Europe")
        my_board = azure.portal.PortalDashboard("my-board",
            name="my-cool-dashboard",
            resource_group_name=example.name,
            location=example.location,
            tags={
                "source": "terraform",
            },
            dashboard_properties=f\"\"\"{{
           \\"lenses\\": {{
                \\"0\\": {{
                    \\"order\\": 0,
                    \\"parts\\": {{
                        \\"0\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 0,
                                \\"rowSpan\\": 2,
                                \\"colSpan\\": 3
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/MarkdownPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"content\\": \\"{md_content}\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"title\\": \\"\\"
                                        }}
                                    }}
                                }}
                            }}
                        }},               
                        \\"1\\": {{
                            \\"position\\": {{
                                \\"x\\": 5,
                                \\"y\\": 0,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/VideoPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"title\\": \\"Important Information\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"src\\": \\"{video_link}\\",
                                            \\"autoplay\\": true
                                        }}
                                    }}
                                }}
                            }}
                        }},
                        \\"2\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 4,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [
                                    {{
                                        \\"name\\": \\"ComponentId\\",
                                        \\"value\\": \\"/subscriptions/{current.subscription_id}/resourceGroups/myRG/providers/microsoft.insights/components/myWebApp\\"
                                    }}
                                ],
                                \\"type\\": \\"Extension/AppInsightsExtension/PartType/AppMapGalPt\\",
                                \\"settings\\": {{}},
                                \\"asset\\": {{
                                    \\"idInputName\\": \\"ComponentId\\",
                                    \\"type\\": \\"ApplicationInsights\\"
                                }}
                            }}
                        }}              
                    }}
                }}
            }},
            \\"metadata\\": {{
                \\"model\\": {{
                    \\"timeRange\\": {{
                        \\"value\\": {{
                            \\"relative\\": {{
                                \\"duration\\": 24,
                                \\"timeUnit\\": 1
                            }}
                        }},
                        \\"type\\": \\"MsPortalFx.Composition.Configuration.ValueTypes.TimeRange\\"
                    }},
                    \\"filterLocale\\": {{
                        \\"value\\": \\"en-us\\"
                    }},
                    \\"filters\\": {{
                        \\"value\\": {{
                            \\"MsPortalFx_TimeRange\\": {{
                                \\"model\\": {{
                                    \\"format\\": \\"utc\\",
                                    \\"granularity\\": \\"auto\\",
                                    \\"relative\\": \\"24h\\"
                                }},
                                \\"displayCache\\": {{
                                    \\"name\\": \\"UTC Time\\",
                                    \\"value\\": \\"Past 24 hours\\"
                                }},
                                \\"filteredPartIds\\": [
                                    \\"StartboardPart-UnboundPart-ae44fef5-76b8-46b0-86f0-2b3f47bad1c7\\"
                                ]
                            }}
                        }}
                    }}
                }}
            }}
        }}
        \"\"\")
        ```

        It is recommended to follow the steps outlined
        [here](https://docs.microsoft.com/azure/azure-portal/azure-portal-dashboards-create-programmatically#fetch-the-json-representation-of-the-dashboard) to create a Dashboard in the Portal and extract the relevant JSON to use in this resource. From the extracted JSON, the contents of the `properties: {}` object can used. Variables can be injected as needed - see above example.

        ### Using a `template_file` data source or the `templatefile` function

        Since the contents of the dashboard JSON can be quite lengthy, use a template file to improve readability:

        `dash.tpl`:

        This is then referenced in the `.tf` file by using a `template_file` data source (terraform 0.11 or earlier), or the `templatefile` function (terraform 0.12+).

        `main.tf` (terraform 0.11 or earlier):

        ```python
        import pulumi
        import pulumi_azurerm as azurerm


        def not_implemented(msg):
            raise NotImplementedError(msg)

        dash_template = not_implemented("The template_file data resource is not yet supported.")
        #...
        my_board = azurerm.index.Dashboard("my-board",
            name=my-cool-dashboard,
            resource_group_name=example.name,
            location=example.location,
            tags={
                source: terraform,
            },
            dashboard_properties=dash_template.rendered)
        ```

        `main.tf` (terraform 0.12+)

        ## Import

        Dashboards can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:portal/portalDashboard:PortalDashboard my-board /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Portal/dashboards/00000000-0000-0000-0000-000000000000
        ```

        Note the URI in the above sample can be found using the Resource Explorer tool in the Azure Portal.


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PortalDashboardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a shared dashboard in the Azure Portal.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        config = pulumi.Config()
        # Content for the MD tile
        md_content = config.get("mdContent")
        if md_content is None:
            md_content = "# Hello all :)"
        # Link to a video
        video_link = config.get("videoLink")
        if video_link is None:
            video_link = "https://www.youtube.com/watch?v=......"
        current = azure.core.get_subscription()
        example = azure.core.ResourceGroup("example",
            name="mygroup",
            location="West Europe")
        my_board = azure.portal.PortalDashboard("my-board",
            name="my-cool-dashboard",
            resource_group_name=example.name,
            location=example.location,
            tags={
                "source": "terraform",
            },
            dashboard_properties=f\"\"\"{{
           \\"lenses\\": {{
                \\"0\\": {{
                    \\"order\\": 0,
                    \\"parts\\": {{
                        \\"0\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 0,
                                \\"rowSpan\\": 2,
                                \\"colSpan\\": 3
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/MarkdownPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"content\\": \\"{md_content}\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"title\\": \\"\\"
                                        }}
                                    }}
                                }}
                            }}
                        }},               
                        \\"1\\": {{
                            \\"position\\": {{
                                \\"x\\": 5,
                                \\"y\\": 0,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [],
                                \\"type\\": \\"Extension/HubsExtension/PartType/VideoPart\\",
                                \\"settings\\": {{
                                    \\"content\\": {{
                                        \\"settings\\": {{
                                            \\"title\\": \\"Important Information\\",
                                            \\"subtitle\\": \\"\\",
                                            \\"src\\": \\"{video_link}\\",
                                            \\"autoplay\\": true
                                        }}
                                    }}
                                }}
                            }}
                        }},
                        \\"2\\": {{
                            \\"position\\": {{
                                \\"x\\": 0,
                                \\"y\\": 4,
                                \\"rowSpan\\": 4,
                                \\"colSpan\\": 6
                            }},
                            \\"metadata\\": {{
                                \\"inputs\\": [
                                    {{
                                        \\"name\\": \\"ComponentId\\",
                                        \\"value\\": \\"/subscriptions/{current.subscription_id}/resourceGroups/myRG/providers/microsoft.insights/components/myWebApp\\"
                                    }}
                                ],
                                \\"type\\": \\"Extension/AppInsightsExtension/PartType/AppMapGalPt\\",
                                \\"settings\\": {{}},
                                \\"asset\\": {{
                                    \\"idInputName\\": \\"ComponentId\\",
                                    \\"type\\": \\"ApplicationInsights\\"
                                }}
                            }}
                        }}              
                    }}
                }}
            }},
            \\"metadata\\": {{
                \\"model\\": {{
                    \\"timeRange\\": {{
                        \\"value\\": {{
                            \\"relative\\": {{
                                \\"duration\\": 24,
                                \\"timeUnit\\": 1
                            }}
                        }},
                        \\"type\\": \\"MsPortalFx.Composition.Configuration.ValueTypes.TimeRange\\"
                    }},
                    \\"filterLocale\\": {{
                        \\"value\\": \\"en-us\\"
                    }},
                    \\"filters\\": {{
                        \\"value\\": {{
                            \\"MsPortalFx_TimeRange\\": {{
                                \\"model\\": {{
                                    \\"format\\": \\"utc\\",
                                    \\"granularity\\": \\"auto\\",
                                    \\"relative\\": \\"24h\\"
                                }},
                                \\"displayCache\\": {{
                                    \\"name\\": \\"UTC Time\\",
                                    \\"value\\": \\"Past 24 hours\\"
                                }},
                                \\"filteredPartIds\\": [
                                    \\"StartboardPart-UnboundPart-ae44fef5-76b8-46b0-86f0-2b3f47bad1c7\\"
                                ]
                            }}
                        }}
                    }}
                }}
            }}
        }}
        \"\"\")
        ```

        It is recommended to follow the steps outlined
        [here](https://docs.microsoft.com/azure/azure-portal/azure-portal-dashboards-create-programmatically#fetch-the-json-representation-of-the-dashboard) to create a Dashboard in the Portal and extract the relevant JSON to use in this resource. From the extracted JSON, the contents of the `properties: {}` object can used. Variables can be injected as needed - see above example.

        ### Using a `template_file` data source or the `templatefile` function

        Since the contents of the dashboard JSON can be quite lengthy, use a template file to improve readability:

        `dash.tpl`:

        This is then referenced in the `.tf` file by using a `template_file` data source (terraform 0.11 or earlier), or the `templatefile` function (terraform 0.12+).

        `main.tf` (terraform 0.11 or earlier):

        ```python
        import pulumi
        import pulumi_azurerm as azurerm


        def not_implemented(msg):
            raise NotImplementedError(msg)

        dash_template = not_implemented("The template_file data resource is not yet supported.")
        #...
        my_board = azurerm.index.Dashboard("my-board",
            name=my-cool-dashboard,
            resource_group_name=example.name,
            location=example.location,
            tags={
                source: terraform,
            },
            dashboard_properties=dash_template.rendered)
        ```

        `main.tf` (terraform 0.12+)

        ## Import

        Dashboards can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:portal/portalDashboard:PortalDashboard my-board /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/rg1/providers/Microsoft.Portal/dashboards/00000000-0000-0000-0000-000000000000
        ```

        Note the URI in the above sample can be found using the Resource Explorer tool in the Azure Portal.


        :param str resource_name: The name of the resource.
        :param PortalDashboardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PortalDashboardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PortalDashboardArgs.__new__(PortalDashboardArgs)

            if dashboard_properties is None and not opts.urn:
                raise TypeError("Missing required property 'dashboard_properties'")
            __props__.__dict__["dashboard_properties"] = dashboard_properties
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["tags"] = tags
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="azure:portal/dashboard:Dashboard")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(PortalDashboard, __self__).__init__(
            'azure:portal/portalDashboard:PortalDashboard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dashboard_properties: Optional[pulumi.Input[_builtins.str]] = None,
            location: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None) -> 'PortalDashboard':
        """
        Get an existing PortalDashboard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dashboard_properties: JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        :param pulumi.Input[_builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.
               
               > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags to assign to the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PortalDashboardState.__new__(_PortalDashboardState)

        __props__.__dict__["dashboard_properties"] = dashboard_properties
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["tags"] = tags
        return PortalDashboard(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="dashboardProperties")
    def dashboard_properties(self) -> pulumi.Output[_builtins.str]:
        """
        JSON data representing dashboard body. See above for details on how to obtain this from the Portal.
        """
        return pulumi.get(self, "dashboard_properties")

    @_builtins.property
    @pulumi.getter
    def location(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name of the Shared Dashboard. Changing this forces a new resource to be created.

        > **Note:** You can specify a tag with the key `hidden-title` to set a more user-friendly title for this Dashboard.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the resource group in which to create the dashboard. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

