# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccessPolicyAssignmentArgs', 'AccessPolicyAssignment']

@pulumi.input_type
class AccessPolicyAssignmentArgs:
    def __init__(__self__, *,
                 managed_redis_id: pulumi.Input[_builtins.str],
                 object_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a AccessPolicyAssignment resource.

        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis instance. Changing this forces a new Access Policy Assignment to be created.
        :param pulumi.Input[_builtins.str] object_id: The object ID of the Azure Active Directory user, group, service principal, or managed identity to assign the access policy to. Changing this forces a new Access Policy Assignment to be created.
               
               > **Note:** Access Policy Assignments are created on the `default` database of the Managed Redis instance.
        """
        pulumi.set(__self__, "managed_redis_id", managed_redis_id)
        pulumi.set(__self__, "object_id", object_id)

    @_builtins.property
    @pulumi.getter(name="managedRedisId")
    def managed_redis_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Managed Redis instance. Changing this forces a new Access Policy Assignment to be created.
        """
        return pulumi.get(self, "managed_redis_id")

    @managed_redis_id.setter
    def managed_redis_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "managed_redis_id", value)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Input[_builtins.str]:
        """
        The object ID of the Azure Active Directory user, group, service principal, or managed identity to assign the access policy to. Changing this forces a new Access Policy Assignment to be created.

        > **Note:** Access Policy Assignments are created on the `default` database of the Managed Redis instance.
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "object_id", value)


@pulumi.input_type
class _AccessPolicyAssignmentState:
    def __init__(__self__, *,
                 managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AccessPolicyAssignment resources.

        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis instance. Changing this forces a new Access Policy Assignment to be created.
        :param pulumi.Input[_builtins.str] object_id: The object ID of the Azure Active Directory user, group, service principal, or managed identity to assign the access policy to. Changing this forces a new Access Policy Assignment to be created.
               
               > **Note:** Access Policy Assignments are created on the `default` database of the Managed Redis instance.
        """
        if managed_redis_id is not None:
            pulumi.set(__self__, "managed_redis_id", managed_redis_id)
        if object_id is not None:
            pulumi.set(__self__, "object_id", object_id)

    @_builtins.property
    @pulumi.getter(name="managedRedisId")
    def managed_redis_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Managed Redis instance. Changing this forces a new Access Policy Assignment to be created.
        """
        return pulumi.get(self, "managed_redis_id")

    @managed_redis_id.setter
    def managed_redis_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "managed_redis_id", value)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The object ID of the Azure Active Directory user, group, service principal, or managed identity to assign the access policy to. Changing this forces a new Access Policy Assignment to be created.

        > **Note:** Access Policy Assignments are created on the `default` database of the Managed Redis instance.
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "object_id", value)


@pulumi.type_token("azure:managedredis/accessPolicyAssignment:AccessPolicyAssignment")
class AccessPolicyAssignment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Managed Redis Access Policy Assignment.

        ## Import

        Managed Redis Access Policy Assignments can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:managedredis/accessPolicyAssignment:AccessPolicyAssignment example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Cache/redisEnterprise/redis1/databases/default/accessPolicyAssignments/00000000-0000-0000-0000-000000000000
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis instance. Changing this forces a new Access Policy Assignment to be created.
        :param pulumi.Input[_builtins.str] object_id: The object ID of the Azure Active Directory user, group, service principal, or managed identity to assign the access policy to. Changing this forces a new Access Policy Assignment to be created.
               
               > **Note:** Access Policy Assignments are created on the `default` database of the Managed Redis instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccessPolicyAssignmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Managed Redis Access Policy Assignment.

        ## Import

        Managed Redis Access Policy Assignments can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:managedredis/accessPolicyAssignment:AccessPolicyAssignment example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Cache/redisEnterprise/redis1/databases/default/accessPolicyAssignments/00000000-0000-0000-0000-000000000000
        ```


        :param str resource_name: The name of the resource.
        :param AccessPolicyAssignmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccessPolicyAssignmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccessPolicyAssignmentArgs.__new__(AccessPolicyAssignmentArgs)

            if managed_redis_id is None and not opts.urn:
                raise TypeError("Missing required property 'managed_redis_id'")
            __props__.__dict__["managed_redis_id"] = managed_redis_id
            if object_id is None and not opts.urn:
                raise TypeError("Missing required property 'object_id'")
            __props__.__dict__["object_id"] = object_id
        super(AccessPolicyAssignment, __self__).__init__(
            'azure:managedredis/accessPolicyAssignment:AccessPolicyAssignment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            managed_redis_id: Optional[pulumi.Input[_builtins.str]] = None,
            object_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AccessPolicyAssignment':
        """
        Get an existing AccessPolicyAssignment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] managed_redis_id: The ID of the Managed Redis instance. Changing this forces a new Access Policy Assignment to be created.
        :param pulumi.Input[_builtins.str] object_id: The object ID of the Azure Active Directory user, group, service principal, or managed identity to assign the access policy to. Changing this forces a new Access Policy Assignment to be created.
               
               > **Note:** Access Policy Assignments are created on the `default` database of the Managed Redis instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccessPolicyAssignmentState.__new__(_AccessPolicyAssignmentState)

        __props__.__dict__["managed_redis_id"] = managed_redis_id
        __props__.__dict__["object_id"] = object_id
        return AccessPolicyAssignment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="managedRedisId")
    def managed_redis_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Managed Redis instance. Changing this forces a new Access Policy Assignment to be created.
        """
        return pulumi.get(self, "managed_redis_id")

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Output[_builtins.str]:
        """
        The object ID of the Azure Active Directory user, group, service principal, or managed identity to assign the access policy to. Changing this forces a new Access Policy Assignment to be created.

        > **Note:** Access Policy Assignments are created on the `default` database of the Managed Redis instance.
        """
        return pulumi.get(self, "object_id")

